@@ -57,64 +57,28 @@ GET <- function(
 
   # 4) set URL
   # to handle
-  curl::handle_setopt(
-    handle = handle,
-    url    = url
-  )
+  # curl::handle_setopt(
+  #   handle = handle,
+  #   url = url
+  # )
 
   # 5) store
   # response in memory
   # and catch connection
   # errors
-  response <- tryCatch(
-    expr = {
-      curl::curl_fetch_memory(
-        url = url,
-        handle = handle
-      )
-    },
-    error = function(error) {
-
-      cli::cli_abort(
-        message = error$message,
-        call    =  sys.call(
-          1 - length(sys.calls())
-        )
-      )
-
-    }
+  response <- curl::curl_fetch_memory(
+    url = url,
+    handle = handle
   )
 
-  response <- tryCatch(
-    expr = {
-      jsonlite::fromJSON(
-        txt = rawToChar(
-          x = response$content
-        ),
-        simplifyVector = TRUE,
-        flatten = TRUE
-      )
-    },
-    error = function(error) {
-
-      cli::cli_abort(
-        message = c(
-          "x" = rawToChar(
-            x = response$content
-          )
-        ),
-        call =  sys.call(
-          1 - length(sys.calls())
-        )
-      )
-
-    }
+  jsonlite::fromJSON(
+    txt = rawToChar(
+      x = response$content
+    ),
+    simplifyVector = TRUE,
+    flatten = TRUE
   )
 
-    response
-
-
-
 }
 
 
@@ -126,8 +90,7 @@ source_parameters <- function(
     interval,
     from,
     to,
-    ...
-) {
+    ...) {
 
   get(
     paste0(
@@ -157,7 +120,7 @@ baseUrl <- function(
   baseUrl <- get(paste0(source, 'Url'))(
     futures = futures,
     ...
-    )
+  )
 
   # 2) return the baseUrl
   return(
@@ -213,7 +176,7 @@ endPoint <- function(
 #'
 #' @returns
 #'
-#' It returns an [xts]-object from the desired endpoint.
+#' It returns an [xts::xts]-object from the desired endpoint.
 #'
 #'
 #' @author Serkan Korkmaz
@@ -313,18 +276,49 @@ fetch <- function(
   #
   # This could be done using do.call
   # maybe
-  switch (source,
-    kraken = {
-      response <- do.call(
-        data.frame,
-        response
+  response <- tryCatch(
+    expr = {
+      switch (
+        source,
+        kraken = {
+          do.call(
+            data.frame,
+            response
+          )
+        },
+        mexc = {
+
+          tryCatch(
+            response[[which(idx)]],
+            error = function(error) {
+              do.call(
+                data.frame,
+                response[
+                  grepl(
+                    pattern = "data",
+                    x = names(response),
+                    ignore.case = TRUE
+                  )
+                ]
+              )
+
+            }
+          )
+
+
+        },
+        response[[which(idx)]]
       )
     },
-    response <- response[[which(idx)]]
+    error = function(error) {
+      assert(
+        FALSE,
+        error_message = error_message
+      )
+    }
   )
 
 
-
   # 3) Extract source specific
   # response parameters
   parameters <- get(
@@ -339,36 +333,49 @@ fetch <- function(
   # 3.1) wrap parameters
   # in tryCatch to check wether
   # the columns exists
-  column_list <- tryCatch(
-    expr = {
-      list(
-        index = response[, parameters$index_location],
-        core  = rbind(response[,parameters$colum_location])
-      )
-    },
-    error = function(error) {
+  # column_list <- tryCatch(
+  #   expr = {
+  #     list(
+  #       index = response[, parameters$index_location],
+  #       core  = rbind(response[,parameters$colum_location])
+  #     )
+  #   },
+  #   error = function(error) {
+  #
+  #     assert(
+  #       FALSE,
+  #       error_message = error_message
+  #     )
+  #
+  #   }
+  # )
 
-      assert(
-        FALSE,
-        error_message = error_message
-      )
-
-    }
-  )
+  # column_list <- list(
+  #   index = response[, parameters$index_location],
+  #   core  = rbind(response[,parameters$colum_location])
+  # )
 
   # 3.1.1) extract the values
   # from the list
-  index <- column_list$index
-  core  <- column_list$core
+
+  # core  <- vapply(
+  #   X         = column_list$core,
+  #   FUN       = as.numeric,
+  #   FUN.VALUE = numeric(1)
+  # )
 
   # 3.1.2) convert
   # all to as.numeric
-  core <- apply(
-    X = core,
-    MARGIN = 2,
-    FUN = as.numeric
+  core <- zoo::as.zoo(
+    apply(
+      X = rbind(response[,parameters$colum_location]),
+      MARGIN = 2,
+      FUN = as.numeric
+    )
   )
 
+
+
   # 3.1.3) convert dates
   # to positxct
   index <- get(
@@ -377,23 +384,18 @@ fetch <- function(
     )
   )(
     futures = futures,
-    dates   = index,
+    dates   = response[, parameters$index_location],
     is_response = TRUE,
     type    = type
   )
 
-
-
-
   # 4) convert to xts
   # from data.frame
   # NOTE: This throws an error
   # for KRAKEN no idea why
   response <- xts::as.xts(
-    zoo::as.zoo(
-      core
-    ),
-    index
+    x = core,
+    order.by = index
   )
   # 4.1) set column
   # names
