@@ -1,16 +1,5 @@
-# script: scr_FUN
-# date: 2023-12-27
-# author: Serkan Korkmaz, serkor1@duck.com
-# objective: Demonstrate the use of the convinience
-# funtions
 # script start;
 
-# by default the Fear and Greed Index
-# is given daily. So to align these values
-# with, say, weekly candles it has to be aggregated
-#
-# In this example the built-in data are used
-
 # 1) check index of BTCUSDT and
 # the Fear and Greed Index
 setequal(
@@ -21,8 +10,8 @@ setequal(
 # 2) to align the indices,
 # we use the convincience functions
 # by splitting the FGI by the BTC index.
-FGIndex <- split_window(
-  xts = FGIndex,
+FGIndex <- cryptoQuotes::split_window(
+  xts = cryptoQuotes::FGIndex,
   by  = zoo::index(BTC),
 
   # Remove upper bounds of the
@@ -38,7 +27,7 @@ FGIndex <- split_window(
 # 3) as splitWindow returns a list
 # it needs to passed into calibrateWindow
 # to ensure comparability
-FGIndex <- calibrate_window(
+FGIndex <- cryptoQuotes::calibrate_window(
   list = FGIndex,
 
   # As each element in the list can include
@@ -53,15 +42,12 @@ FGIndex <- calibrate_window(
 
 # 3) check if candles aligns
 # accordingly
-setequal(
-  zoo::index(BTC),
-  zoo::index(FGIndex)
+stopifnot(
+  setequal(
+    zoo::index(BTC),
+    zoo::index(FGIndex)
+  )
 )
 
 
-# As the dates are now aligned
-# and the Fear and Greed Index being summarised by
-# the first value, the Fear and Greed Index is the opening
-# Fear and Greed Index value, at each candle.
-
 # script end;
