@@ -11,7 +11,8 @@ testthat::test_that(
 
     # 0) skip if offline
     # and on github
-    testthat::skip_if_offline(); testthat::skip_on_ci()
+    testthat::skip_if_offline()
+    testthat::skip_on_ci()
 
     # 1) create a vector
     # of available exchanges
@@ -20,7 +21,10 @@ testthat::test_that(
       'bitmart',
       'bybit',
       'kraken',
-      'kucoin'
+      'kucoin',
+      "crypto.com",
+      "mexc",
+      "huobi"
     )
 
     # 2) start loop
@@ -41,32 +45,44 @@ testthat::test_that(
 
           ticker <- switch(
             exchange,
-            "binance" = "BTCUSDT",
-            "bybit"   = "BTCUSDT",
-            "bitmart" = "BTCUSDT",
-            "kraken"  = "PF_XBTUSD",
-            "kucoin"  = "XBTUSDTM"
+            "binance"    = "BTCUSDT",
+            "bybit"      = "BTCUSDT",
+            "bitmart"    = "ETHUSDT",
+            "kraken"     = "PF_XBTUSD",
+            "kucoin"     = "XBTUSDTM",
+            "crypto.com" = "BTCUSD-PERP",
+            "mexc"       = "BTC_USDT",
+            "huobi"      = "BTC-USDT"
           )
 
         } else {
 
           ticker <- switch(
             exchange,
-            "binance" = "BTCUSDT",
-            "bybit"   = "BTCUSDT",
-            "bitmart" = "BTC_USDT",
-            "kraken"  = "XBTUSDT",
-            "kucoin"  = "BTC-USDT"
+            "binance"    = "BTCUSDT",
+            "bybit"      = "BTCUSDT",
+            "bitmart"    = "ETH_USDT",
+            "kraken"     = "XBTUSDT",
+            "kucoin"     = "BTC-USDT",
+            "crypto.com" = "BTC_USDT",
+            "mexc"       = "BTCUSDT",
+            "huobi"      = "btcusdt"
           )
 
         }
 
         # 2) for each market we
         # test two intervals
-        intervals <- c("1d", "1h")
+        suppressMessages(
+          intervals <- available_intervals(
+            source  = exchange,
+            futures = futures
+          )
+        )
 
         for (interval in intervals) {
 
+
           error_label <- paste(
             "Error in get_quote for",
             exchange,
@@ -76,38 +92,53 @@ testthat::test_that(
             interval
           )
 
-          # 1) Return quote on
-          # from exchanges
-          testthat::expect_no_condition(
-            output <- get_quote(
+
+          output <- try(
+            get_quote(
               ticker   = ticker,
               source   = exchange,
               interval = interval,
               futures  = futures
+            )
+          )
+
+          # 1) Return quote on
+          # from exchanges
+          testthat::expect_false(
+            object = inherits(
+              x = output,
+              what = "try-error"
             ),
-            message = error_label
+            label = paste(error_label, "(Test 0)")
           )
 
           # 2) test wether the
           # ohlc is logical
           testthat::expect_true(
             all(
-              output$high >= output$low,
-              output$open >= output$low,
-              output$open <= output$high,
+              output$high  >= output$low,
+              output$open  >= output$low,
+              output$open  <= output$high,
               output$close >= output$low,
               output$close <= output$high
             ),
-            label = error_label
+            label = paste(error_label, "(Test 1)")
           )
 
+          testthat::expect_true(
+            setequal(
+              x = infer_interval(output),
+              y = interval
+            ),
+            label = paste(error_label, "(Expected Interval)")
+          )
           # 2) check if the returned
           # quote is 100 +/-
           testthat::expect_equal(
             object = nrow(output),
             tolerance = 1,
             expected = 200,
-            label = error_label
+            label = paste(error_label, "(Test 2)")
           )
 
           # 3) test if dates are reasonable
@@ -126,7 +157,18 @@ testthat::test_that(
               min(date_range) >= 2000,
               max(date_range) <= as.numeric(format(Sys.Date(), "%Y"))
             ),
-            label = error_label
+            label = paste(error_label, "(Test 3)")
+          )
+
+          # 4) test that the inferred interval
+          # corresponds to the passed interval
+          testthat::expect_true(
+            setequal(
+              interval,
+              cryptoQuotes:::infer_interval(
+                output
+              )
+            )
           )
 
 
@@ -138,3 +180,4 @@ testthat::test_that(
 
   }
 )
+
